@@ -23,22 +23,22 @@ class Activity(BasePolarion):
         source_id (string)
         timestamp (dateTime)
         type (string)
-        user_id (string)
-"""
-    _cls_suds_map = {"activity_custom_values": "activity_custom_values",
-                     "comments": "comments",  # array of ActivityComment
-                     "global_id": "globalId",
-                     "activity_id": "id",
-                     "info":
-                     {"field_name": "info",
-                      "cls": Text},
-                     "prefix": "prefix",
-                     "resource_locations": "resourceLocations",
-                     "source_id": "sourceId",
-                     "timestamp": "timestamp",
-                     "type": "type",
-                     "user_id": "userId",
-                     "uri": "_uri",
-                     "_unresolved": "_unresolved"}
+        user_id (string)"""
+
+    _cls_suds_map = {
+        "activity_custom_values": "activity_custom_values",
+        "comments": "comments",  # array of ActivityComment
+        "global_id": "globalId",
+        "activity_id": "id",
+        "info": {"field_name": "info", "cls": Text},
+        "prefix": "prefix",
+        "resource_locations": "resourceLocations",
+        "source_id": "sourceId",
+        "timestamp": "timestamp",
+        "type": "type",
+        "user_id": "userId",
+        "uri": "_uri",
+        "_unresolved": "_unresolved",
+    }
     _obj_client = "tracker_client"
     _obj_struct = "tns3:Activity"
