@@ -16,10 +16,11 @@ class ActivityComment(BasePolarion):
         time_stamp (dateאime)
         user_id (string)
     """
-    _cls_suds_map = {"text":
-                     {"field_name": "text",
-                      "cls": Text},
-                     "time_stamp": "timeStamp",
-                     "user_id": "userId"}
+
+    _cls_suds_map = {
+        "text": {"field_name": "text", "cls": Text},
+        "time_stamp": "timeStamp",
+        "user_id": "userId",
+    }
     _obj_client = "tracker_client"
     _obj_struct = "tns3:ActivityComment"
